/*
Required modules:
	xtabond2
	regsave
	calcpe

Required input files:	
	physician_and_laws_replication_censored.dta
	REIS_data.dta

Output files:
	pundam.csv     (Figure 1)
	medmal.csv     (Figure 5)
	pc_income.csv  (Figure 6a)
	pc_Medi.csv    (Figure 6b)
	tables_raw.csv (Tables 4-11)
*/

*********************
* Initialization
*********************

* Set this local equal to the folder location for this script, e.g., "C:/Users/name/myfolder/"
local workdir ""

version 14
clear
set more off
set varabbrev off
set matsize 5000
mata: mata set matafavor speed
local reg_set "cmdline t p"
tempfile core_data

* Set the flag equal to 1 to run that analysis, and equal to 0 otherwise
* Note: with the cnensored data, only the figure_6 analysis can be run
local figures_1_and_5 = 0
local figure_6 = 1
local tables = 0

*****************************
* Set up data for analysis
*****************************

use "`workdir'Data/physician_and_laws_replication_censored.dta", clear
tempfile results tmp_results

* Merge on state-level control variables
ren state abbr
merge m:1 abbr year using "`workdir'Data/REIS_data.dta", assert(match) nogenerate keepusing(Medi pc_income)
ren abbr state
gen pc_Medi = Medi/pop
drop Medi

* Declare our panel data
tsset statespec year, year

* Generate lags and leads
local all_tortvars "nonecon medmal collateral joint contingent periodic pundam pundamevid split fund"
local num_leads = 5
local num_lags  = 5
qui foreach v of local all_tortvars {
	qui forval x = 0/`num_leads' {
		gen F`x'_`v' = year==`v'_ondt-`x'
	}
	qui forval x = 1/`num_lags' {
		gen L`x'_`v' = year==`v'_ondt+`x'
	}	
}
compress
save "`core_data'", replace

************************************************************************************
* Figures 1, 5, and 6
************************************************************************************

if `figures_1_and_5'==1 | `figure_6'==1 {
	* Encode specyear so we can use it as factor variable in -areg-
	encode specyear, gen(specyear2)
	drop specyear
	ren specyear2 specyear
	preserve
	
	* Create event-study figures for punitive damage caps and total damage caps
	qui foreach v in pundam medmal {
	
		* Create rhs vars
		local rhs ""
		forval x = 0/`num_leads' {
			local rhs "`rhs' F`x'_`v'"
		}
		forval x = 1/`num_lags' {
			local rhs "`rhs' L`x'_`v'"
		}			

		if `figures_1_and_5'==1 {
			* Run event-study regression. Note: uses the interpolated (1984, 1990) dependent variable
			areg _lndocspc `rhs' i.specyear [aw=pop], cluster(statespec) absorb(statespec)

			local to_save = ""
			forval x = 0/`num_leads' {
				local to_save "`to_save' F`x'_`v'"
			}
			forval x = 1/`num_lags' {
				local to_save "`to_save' L`x'_`v'"
			}					

			* Save estimated coefficients, format variables, and outsheet the results for Figures 1 and 5
			regsave `to_save', ci

			gen year = "-" + substr(var,2,2) if substr(var,1,1)=="F"
			replace year = substr(var,2,2) if substr(var,1,1)=="L"
			replace year = subinstr(year,"_","",1)
			destring year, replace
			gen y = coef
			sort year
			outsheet using "`workdir'results/`v'.csv", comma replace
		}
		restore, preserve

		* Check whether we are balanced on covariates at the state level in the case of punitive damage caps
		foreach bal_var in pc_Medi pc_income {
		
			if `figure_6'==1 {
				if "`v'"!="pundam" continue
				bysort state year: keep if _n==1
				areg `bal_var' `rhs' i.year [aw=pop], cluster(state) absorb(state)
				
				* Save estimated coefficients, format variables, and outsheet the results for Figure 6
				regsave F?_`v' L?_`v', ci

				gen year = "-" + substr(var,2,2) if substr(var,1,1)=="F"
				replace year = substr(var,2,2) if substr(var,1,1)=="L"
				replace year = subinstr(year,"_","",1)
				destring year, replace
				gen y = coef
				sort year
				outsheet using "`workdir'results/`bal_var'.csv", comma replace
			}
			restore, preserve
		}
		
	}
	restore
}
use "`core_data'", clear


************************************************************************************
* Tables 4-11
************************************************************************************
if `tables'==1 {

	* Create fixed effects
	gen trend = year-1980
	xi I.specyear I.state*trend

	gen to_use = 1
	gen to_use_window = 1

	local run_no = 0
	local replace replace

	foreach fe in "_Ispecyear*" "_Ispecyear* _IstaXtren*"    {
	foreach if2 in "" `"inlist(state,"VA", "IL","OR","WI","PA")"'  {
	foreach tort_controls in "all" "none"  {

		noi di in yellow "Run number `=`run_no'+1'"
		
		* Define our to_use variable
		replace to_use = 1
		replace to_use = 0 if risk!=1
		if "`if2'"!="" replace to_use = 0 if `if2'
		
		* Define the parameters for the 9-year pre-post moving window
		local exclude_pd_pre = 5
		local exclude_pd_post = 4

		replace to_use_window = to_use
		replace to_use_window = 0 if (year < pundam_ondt - `exclude_pd_pre' & !mi(pundam_ondt)) | (year > pundam_ondt + `=`exclude_pd_post'-1' & !mi(pundam_ondt))
		local touse = "to_use_window"
		
		* Define labels
		local if2_lab : subinstr local if2 `"""' "", all
				
		* Define rhs vars
		if "`tort_controls'"=="none" local xvars "pundam"
		if "`tort_controls'"=="all"  local xvars "`all_tortvars'"
		local xvarsG ""
		local xvarsD ""
		foreach v of local xvars {
			local xvarsG "`xvarsG' L.`v'"
			local xvarsD "`xvarsD' F.`v'"
		}
		sort statespec year

		local reg_labels `"fe,`fe',tort_controls,`tort_controls',excluded_states,":`if2_lab'""'

		**************
		* Myopic OLS * (Table 4)
		**************		
		noi di in yellow _n"Starting myopic regs:"		

		qui areg lndocspc `xvars' `fe' [aw=pop] if `touse', absorb(statespec) cluster(state)		
		regsave using "`results'", addlabel(Scenario,Myopic model,Case,"Leads: 0",`reg_labels') `replace' `reg_set'
		
		local replace append

		******************************
		* OLS Quasi-myopic estimates * (Tables 5 and 6)
		******************************
		noi di in yellow _n"Starting quasi-myopic regs"
				
		qui forval leads = 1/4 {
		
			* Create rhs lead vars
			local rhs ""
			local v "pundam"

			forval x = 1/`leads' {
				local rhs "`rhs' F`x'_`v'"
			}			
			qui areg lndocspc `rhs' `xvars' `fe'  [aw=pop] if `touse', absorb(statespec) cluster(state)

			regsave using "`results'", addlabel(Scenario,quasi_myopic,Case,"Leads: `leads'",`reg_labels') append `reg_set'
		}
		
		*******************************
		* OLS estimates	              * (OLS, Tables 7 and 8)
		*******************************
		qui areg lndocspc F.lndocspc `xvars' `xvarsD' `fe'  [aw=pop] if `touse', absorb(statespec) cluster(state)
		
		* Calculate permanent effects
		local added_vars ""
		foreach x of local xvars {
			if !inlist("`x'","pundam") continue					
			calcpe `x' F.lndocspc
			local added_vars "`added_vars',PE (`x'), `r(ratio)', `r(stderr_ratio)', EA1 (`x'), `r(ratio1)', `r(stderr_ratio1)', EA2 (`x'), `r(ratio2)', `r(stderr_ratio2)', EA3 (`x'), `r(ratio3)', `r(stderr_ratio3)', EA4 (`x'), `r(ratio4)', `r(stderr_ratio4)'"
			local tstat = `r(ratio5)'/`r(stderr_ratio5)'
			local EAtestp = tprob(`e(df_r)', abs(`tstat'))			
		}
		local added_vars : subinstr local added_vars "," ""
		
		regsave using "`results'", addlabel(Scenario,ols_ee,Case,"Leads:",EAtestp,`EAtestp',`reg_labels') addvar(`added_vars') `reg_set' append

		*******************************
		* Dynamic panel IV  estimates * (IV, Tables 7, 8, and 9)
		*******************************

		local rhs "F.lndocspc `xvars' `xvarsD' `fe'"
		local ivs "iv(`xvars' `xvarsD' `fe')"

		* Main specs: lags and leads
		local lag_ivs_orthog "gmm(lndocspc, laglimits(2 .)) orthog"
		local lead_ivs_orthog "gmm(lndocspc, laglimits(-2 -25)) reverseorthog"
		
		* Robustness specs: 1 lead only (t+2 or t+3)
		local lead_ivs_orthog_lead2only "gmm(lndocspc, laglimits(-2 -2)) reverseorthog"
		local lead_ivs_orthog_lead3only "gmm(lndocspc, laglimits(-3 -3)) reverseorthog"

		qui foreach scen in lead_ivs_orthog lag_ivs_orthog lead_ivs_orthog_lead2only lead_ivs_orthog_lead3only {
		
			qui xtabond2 lndocspc `rhs'  [aw=pop] if `touse', nolevel cluster(state) nodiffsargan h(2) artests(3) small ``scen'' `ivs'

			* Calculate ex post and ex ante effects
			local added_vars ""
			foreach x of local xvars {
				if !inlist("`x'","pundam") continue	
				cap calcpe `x' F.lndocspc
				if !_rc local added_vars "`added_vars',PE (`x'), `r(ratio)', `r(stderr_ratio)', EA1 (`x'), `r(ratio1)', `r(stderr_ratio1)', EA2 (`x'), `r(ratio2)', `r(stderr_ratio2)', EA3 (`x'), `r(ratio3)', `r(stderr_ratio3)', EA4 (`x'), `r(ratio4)', `r(stderr_ratio4)'"
				local tstat = `r(ratio5)'/`r(stderr_ratio5)'
				local EAtestp = tprob(`e(df_r)', abs(`tstat'))
			}
			local added_vars : subinstr local added_vars "," ""

			* Grab serial correlation tests
			local AR_vals ""
			local val = `e(ar3p)'
			if `val'==. local val = -999
			local AR_vals "`AR_vals', AR_3p, `val'"

			regsave using "`results'", addlabel(Scenario,1_`scen'_RE,Case,"Leads:",EAtestp,`EAtestp',`reg_labels'`AR_vals') addvar(`added_vars') `reg_set' append
		}
		
		*******************************
		* End	                      * 
		*******************************	

		local run_no = `run_no'+1
	}	
	}
	}

	* Output main regression results to "tables_raw.csv". The raw output is linked to, and organized by, the Excel file "tables.xlsx".
	use "`results'", clear
	drop if strpos(var,"_I")!=0
	drop if strpos(var,"#c.year")
	outsheet using "`workdir'results/tables_raw.csv", comma replace
}


** EOF
